summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_build_service.sh
diff options
context:
space:
mode:
authorVagrant Cascadian <vagrant@debian.org>2017-08-02 17:03:03 -0400
committerHolger Levsen <holger@layer-acht.org>2017-08-03 16:22:39 -0400
commit4c5ea6af7385064575531b1572c9bebf999b005d (patch)
treec8528a53c4157d3e5b945149e887f5eaf117a247 /bin/reproducible_build_service.sh
parent34c1dd358e6879664f12703ccdcd1e88f11854b1 (diff)
downloadjenkins.debian.net-4c5ea6af7385064575531b1572c9bebf999b005d.tar.xz
reproducible: Add two new armhf builders (jtk1b, jtx1b).
Temporarily disable two armhf build nodes (jtk1a down, ff64a too slow). Add an additional build job, as the new machines have more capacity than the old. Signed-off-by: Holger Levsen <holger@layer-acht.org>
Diffstat (limited to 'bin/reproducible_build_service.sh')
-rwxr-xr-xbin/reproducible_build_service.sh21
1 files changed, 11 insertions, 10 deletions
diff --git a/bin/reproducible_build_service.sh b/bin/reproducible_build_service.sh
index 0b148214..abcda366 100755
--- a/bin/reproducible_build_service.sh
+++ b/bin/reproducible_build_service.sh
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_31) NODE1=codethink-sled14-arm64 NODE2=codethink-sled11-arm64 ;;
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
# for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram
# 4 jobs for hexa-cores with 2 gb ram
@@ -142,22 +142,22 @@ choose_nodes() {
armhf_13) NODE1=ff2a-armhf-rb NODE2=p64c-armhf-rb ;;
armhf_14) NODE1=ff2b-armhf-rb NODE2=p64b-armhf-rb ;;
armhf_15) NODE1=ff2b-armhf-rb NODE2=opi2c-armhf-rb ;;
- armhf_16) NODE1=ff64a-armhf-rb NODE2=p64b-armhf-rb ;;
- armhf_17) NODE1=ff64a-armhf-rb NODE2=opi2c-armhf-rb ;;
- armhf_18) NODE1=jtk1a-armhf-rb NODE2=opi2b-armhf-rb ;;
- armhf_19) NODE1=jtk1a-armhf-rb NODE2=opi2a-armhf-rb ;;
+ armhf_16) NODE1=jtx1b-armhf-rb NODE2=p64b-armhf-rb ;;
+ armhf_17) NODE1=jtx1b-armhf-rb NODE2=opi2c-armhf-rb ;;
+ armhf_18) NODE1=jtk1b-armhf-rb NODE2=opi2b-armhf-rb ;;
+ armhf_19) NODE1=jtk1b-armhf-rb NODE2=opi2a-armhf-rb ;;
armhf_20) NODE1=odxu4-armhf-rb NODE2=opi2b-armhf-rb ;;
armhf_21) NODE1=odxu4-armhf-rb NODE2=opi2a-armhf-rb ;;
armhf_22) NODE1=odxu4b-armhf-rb NODE2=odu3a-armhf-rb ;;
- armhf_23) NODE1=odxu4b-armhf-rb NODE2=jtk1a-armhf-rb ;;
+ armhf_23) NODE1=odxu4b-armhf-rb NODE2=jtk1b-armhf-rb ;;
armhf_24) NODE1=odxu4c-armhf-rb NODE2=odu3a-armhf-rb ;;
- armhf_25) NODE1=odxu4c-armhf-rb NODE2=jtk1a-armhf-rb ;;
+ armhf_25) NODE1=odxu4c-armhf-rb NODE2=jtk1b-armhf-rb ;;
armhf_26) NODE1=odu3a-armhf-rb NODE2=odxu4-armhf-rb ;;
- armhf_27) NODE1=odu3a-armhf-rb NODE2=ff64a-armhf-rb ;;
+ armhf_27) NODE1=odu3a-armhf-rb NODE2=jtx1b-armhf-rb ;;
armhf_28) NODE1=opi2a-armhf-rb NODE2=odxu4c-armhf-rb ;;
armhf_29) NODE1=opi2a-armhf-rb NODE2=cbxi4a-armhf-rb ;;
armhf_30) NODE1=opi2b-armhf-rb NODE2=odxu4c-armhf-rb ;;
- armhf_31) NODE1=opi2b-armhf-rb NODE2=ff64a-armhf-rb ;;
+ armhf_31) NODE1=opi2b-armhf-rb NODE2=jtx1b-armhf-rb ;;
armhf_32) NODE1=opi2c-armhf-rb NODE2=odxu4b-armhf-rb ;;
armhf_33) NODE1=opi2c-armhf-rb NODE2=ff2a-armhf-rb ;;
armhf_34) NODE1=p64b-armhf-rb NODE2=odxu4b-armhf-rb ;;
@@ -166,7 +166,7 @@ choose_nodes() {
armhf_37) NODE1=p64c-armhf-rb NODE2=cbxi4pro0-armhf-rb ;;
armhf_38) NODE1=wbq0-armhf-rb NODE2=ff2b-armhf-rb ;;
armhf_39) NODE1=wbq0-armhf-rb NODE2=cbxi4pro0-armhf-rb ;;
- armhf_40) NODE1=cbxi4a-armhf-rb NODE2=bbx15-armhf-rb ;;
+ armhf_40) NODE1=cbxi4a-armhf-rb NODE2=jtx1b-armhf-rb ;;
armhf_41) NODE1=cbxi4a-armhf-rb NODE2=cb3a-armhf-rb ;;
armhf_42) NODE1=cbxi4a-armhf-rb NODE2=rpi2c-armhf-rb ;;
armhf_43) NODE1=cbxi4b-armhf-rb NODE2=bbx15-armhf-rb ;;
@@ -178,6 +178,7 @@ choose_nodes() {
armhf_49) NODE1=jtx1a-armhf-rb NODE2=cbxi4a-armhf-rb ;;
armhf_50) NODE1=jtx1a-armhf-rb NODE2=rpi2b-armhf-rb ;;
armhf_51) NODE1=jtx1a-armhf-rb NODE2=odxu4-armhf-rb ;;
+ armhf_52) NODE1=jtx1b-armhf-rb NODE2=bbx15-armhf-rb ;;
*) NODE1=undefined
;;
esac
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
- # for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
+ # for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram